@@ -1,5 +1,5 @@
 // some very small jquery extensions
-(function($) {
+(function namespacing($) {
 	// very simple yellow fade plugin..
 	$.fn.yft = function(){ this.effect("highlight", {}, 1000); };
 	
@@ -223,7 +223,37 @@
 			if(jtarget.hasClass("publish-checkbox")) {
 				pageId = jtarget.attr("name").split("status-")[1];
 				// if I don't put data in the post, django doesn't get it
-				reloadItem(jtarget, admin_base_url + "cms/page/" + pageId + "/change-status/", { 1:1 });
+				reloadItem(
+						jtarget, admin_base_url + "cms/page/" + pageId + "/change-status/",
+						{ 1:1 },
+						// on success
+						function(decoded,textStatus){
+							response = decoded.content;
+							status = decoded.status;
+							if(status==200) {
+								if (/page_\d+/.test($(jtarget).attr('id'))) {
+									// one level higher
+									target = $(jtarget).find('div.cont:first');
+								} else {
+									target = $(jtarget).parents('div.cont:first');
+								}
+
+								var parent = target.parent();
+								if (response == "NotFound") {
+									return parent.remove();
+								}
+								target.replace(response);
+								parent.find('div.cont:first').yft();
+
+								return false;
+							}
+							else {
+								$(jtarget).attr("checked",false)
+								alert(response);
+								return false;
+							}
+						}
+				);
 				e.stopPropagation();
 				return true;
 			}
@@ -264,28 +294,28 @@
 				// of the tree = current node + descendants 
 				reloadItem(jtarget, admin_base_url + "cms/page/" + pageId + "/approve/?node=1", {}, refreshIfChildren(pageId));
 				e.stopPropagation();
-	            return false;
-	        }
+				return false;
+			}
 
-	        // lazy load descendants on tree open
-	        if(jtarget.hasClass("closed")) {
-	        	// only load them once
-	        	if(jtarget.find('ul > li').length == 0 && !jtarget.hasClass("loading")) {
-	        		// keeps this event from firing multiple times before
-	        		// the dom as changed. it still needs to propagate for 
-	        		// the other click event on this element to fire
-                    jtarget.addClass("loading");
-                    var pageId = $(jtarget).attr("id").split("page_")[1];
-
-                    $.get(admin_base_url + "cms/page/" + pageId + "/descendants/", {}, function(r, status) {
-                        jtarget.children('ul').append(r);    
-                        // show move targets if needed
-                        if($('span.move-target-container:visible').length > 0) {
-                        	jtarget.children('ul').find('a.move-target, span.move-target-container, span.line').show();
-                        }
-                    });
-                }
-	        }
+			// lazy load descendants on tree open
+			if(jtarget.hasClass("closed")) {
+				// only load them once
+				if(jtarget.find('ul > li').length == 0 && !jtarget.hasClass("loading")) {
+					// keeps this event from firing multiple times before
+					// the dom as changed. it still needs to propagate for 
+					// the other click event on this element to fire
+					jtarget.addClass("loading");
+					var pageId = $(jtarget).attr("id").split("page_")[1];
+					
+					$.get(admin_base_url + "cms/page/" + pageId + "/descendants/", {}, function(r, status) {
+						jtarget.children('ul').append(r);    
+						// show move targets if needed
+						if($('span.move-target-container:visible').length > 0) {
+							jtarget.children('ul').find('a.move-target, span.move-target-container, span.line').show();
+						};
+					});
+				}
+			}
 			
 			if(jtarget.hasClass("move-target")) {
 				if(jtarget.hasClass("left")){
@@ -321,8 +351,8 @@
 				var val= $(this).width();
 				if(val > max){max = val;}
 			});
-	 		$(this).each(function() {
-	  			$(this).css("width",max + 'px');
+			$(this).each(function() {
+				$(this).css("width",max + 'px');
 			});
 			return this;
 		};
@@ -399,12 +429,15 @@
 			};
 			data = $.extend(data, options);
 			
-			$.post("./" + item_id + "/copy-page/", data, function(html) {
-				if(html=="ok"){
+			$.post("./" + item_id + "/copy-page/", data, function(decoded) {
+				response = decoded.content;
+				status = decoded.status;
+				if(status==200) {
 					// reload tree
 					window.location = window.location.href;
 				}else{
-					moveError($('#page_'+item_id + " div.col1:eq(0)"));  
+					alert(response);
+					moveError($('#page_'+item_id + " div.col1:eq(0)"),response);
 				}
 			});
 		}
@@ -438,21 +471,24 @@
 		}
 		
 		function onSuccess(response, textStatus) {
-			if (callback) callback(response, textStatus);
-			
-			if (/page_\d+/.test($(el).attr('id'))) {
-				// one level higher
-				target = $(el).find('div.cont:first');
-			} else { 
-				target = $(el).parents('div.cont:first');
+			status = true;
+			if (callback) status = callback(response, textStatus);
+
+			if(status==true) {
+				if (/page_\d+/.test($(el).attr('id'))) {
+					// one level higher
+					target = $(el).find('div.cont:first');
+				} else {
+					target = $(el).parents('div.cont:first');
+				}
+
+				var parent = target.parent();
+				if (response == "NotFound") {
+					return parent.remove();
+				}
+				target.replace(response);
+				parent.find('div.cont:first').yft();
 			}
-			
-			var parent = target.parent();
-			if (response == "NotFound") {
-				return parent.remove();
-			}
-			target.replace(response);
-			parent.find('div.cont:first').yft();
 
 			return true;
 		}
@@ -476,21 +512,25 @@
 		reloadItem(
 			jtarget, "./" + item_id + "/move-page/", 
 			
-			{ position: position, target: target_id }, 
-			
+			{ position: position, target: target_id },
+
 			// on success
-			function(){
-				if (tree) {
-					var tree_pos = {'left': 'before', 'right': 'after'}[position] || 'inside';
-					tree.moved("#page_" + item_id, $("#page_" + target_id + " a.title")[0], tree_pos, false, false);
-				} else {
-					moveSuccess($('#page_'+item_id + " div.col1:eq(0)"));
+			function(decoded,textStatus){
+				response = decoded.content;
+				status = decoded.status;
+				if(status==200) {
+					if (tree) {
+						var tree_pos = {'left': 'before', 'right': 'after'}[position] || 'inside';
+						tree.moved("#page_" + item_id, $("#page_" + target_id + " a.title")[0], tree_pos, false, false);
+					} else {
+						moveSuccess($('#page_'+item_id + " div.col1:eq(0)"));
+					}
+					return false;
+				}
+				else {
+					moveError($('#page_'+item_id + " div.col1:eq(0)"),response);
+					return false;
 				}
-			},
-			
-			// on error
-			function(){
-				moveError($('#page_'+item_id + " div.col1:eq(0)"));
 			}
 		);
 	}
@@ -500,4 +540,4 @@
 	function addUndo(node, target, position){
 		undos.push({node:node, target:target, position:position});
 	}
-})(jQuery);
+})(window.CMS.$);
