@@ -1,27 +1,25 @@
 # -*- coding: utf-8 -*-
 from __future__ import with_statement
 
+from django.contrib.sites.models import Site
+from django.contrib.auth.models import AnonymousUser, User, Group
+from django.test.client import Client
+
 from cms.api import create_page
-from cms.menu import CMSMenu, get_visible_pages
+from cms.menu import get_visible_pages
 from cms.models import Page
 from cms.models import ACCESS_DESCENDANTS, ACCESS_CHILDREN, ACCESS_PAGE
 from cms.models import ACCESS_PAGE_AND_CHILDREN, ACCESS_PAGE_AND_DESCENDANTS 
 from cms.models.permissionmodels import GlobalPagePermission, PagePermission
-from cms.models.titlemodels import Title
 from cms.test_utils.testcases import SettingsOverrideTestCase
 
-from django.contrib.sites.models import Site
-from django.contrib.auth.models import AnonymousUser, User, Permission, Group
-from django.db.models import Q
-from django.test.client import Client
-
 
 class ViewPermissionTests(SettingsOverrideTestCase):
     """
     Test various combinations of view permissions pages and menus
     Focus on the different grant types and inheritance options of grant on
     Given the tree:
-        
+
         |- Page_a
         |- Page_b
         | |- Page_b_a
@@ -46,15 +44,15 @@ class ViewPermissionTests(SettingsOverrideTestCase):
     GROUPNAME_3 = 'group_b_ACCESS_PAGE_AND_DESCENDANTS'
     GROUPNAME_4 = 'group_b_b_ACCESS_DESCENDANTS'
     GROUPNAME_5 = 'group_d_ACCESS_PAGE'
-    
+
     def setUp(self):
         self.site = Site()
         self.site.pk = 1
         super(ViewPermissionTests, self).setUp()
-       
+
     def tearDown(self):
         super(ViewPermissionTests, self).tearDown()
-    
+
     def _setup_tree_pages(self):
         stdkwargs = {
             'template': 'nav_playground.html',
@@ -66,25 +64,25 @@ class ViewPermissionTests(SettingsOverrideTestCase):
         page_b = create_page("page_b", **stdkwargs)
         page_c = create_page("page_c", **stdkwargs)
         page_d = create_page("page_d", **stdkwargs)
-        
+
         page_b_a = create_page("page_b_a", parent=page_b, **stdkwargs)
         page_b_b = create_page("page_b_b", parent=page_b, **stdkwargs)
         page_b_b_a = create_page("page_b_b_a", parent=page_b_b, **stdkwargs)
         page_b_b_b = create_page("page_b_b_b", parent=page_b_b, **stdkwargs)
         page_b_b_c = create_page("page_b_b_c", parent=page_b_b, **stdkwargs)
         page_b_b_a_a = create_page("page_b_b_a_a", parent=page_b_b_a, **stdkwargs)
-        
+
         page_b_c = create_page("page_b_c", parent=page_b, **stdkwargs)
         page_b_d = create_page("page_b_d", parent=page_b, **stdkwargs)
         page_b_d_a = create_page("page_b_d_a", parent=page_b_d, **stdkwargs)
         page_b_d_b = create_page("page_b_d_b", parent=page_b_d, **stdkwargs)
         page_b_d_c = create_page("page_b_d_c", parent=page_b_d, **stdkwargs)
-        
+
         page_d_a = create_page("page_d_a", parent=page_d, **stdkwargs)
         page_d_b = create_page("page_d_b", parent=page_d, **stdkwargs)
         page_d_c = create_page("page_d_c", parent=page_d, **stdkwargs) 
         page_d_d = create_page("page_d_d", parent=page_d, **stdkwargs)
-        
+
         return [page_a,
                 page_b,
                 page_b_a,
@@ -105,7 +103,7 @@ class ViewPermissionTests(SettingsOverrideTestCase):
                 page_d_c,
                 page_d_d,
     ]
-        
+
     def _setup_user_groups(self):
         """
         Setup a group for every grant on ACCESS TYPE
@@ -116,72 +114,72 @@ class ViewPermissionTests(SettingsOverrideTestCase):
         group = Group.objects.create(name=self.GROUPNAME_1)
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_1_nostaff', email='user_1_nostaff@domain.com', is_active=True, is_staff=False)
         user.set_password(user.username)
         user.save()
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_2', email='user_2@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
         user.save()
         group = Group.objects.create(name=self.GROUPNAME_2)
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_2_nostaff', email='user_2_nostaff@domain.com', is_active=True, is_staff=False)
         user.set_password(user.username)
         user.save()
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_3', email='user_3@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
         user.save()
         group = Group.objects.create(name=self.GROUPNAME_3)
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_3_nostaff', email='user_3_nostaff@domain.com', is_active=True, is_staff=False)
         user.set_password(user.username)
         user.save()
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_4', email='user_4@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
         user.save()
         group = Group.objects.create(name=self.GROUPNAME_4)
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_4_nostaff', email='user_4_nostaff@domain.com', is_active=True, is_staff=False)
         user.set_password(user.username)
         user.save()
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_5', email='user_5@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
         user.save()
         group = Group.objects.create(name=self.GROUPNAME_5)
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_5_nostaff', email='user_5_nostaff@domain.com', is_active=True, is_staff=False)
         user.set_password(user.username)
         user.save()
         group.user_set.add(user)
         group.save()
-        
+
         user = User.objects.create(username='user_staff', email='user_staff@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
         user.save()
-        
+
         self.assertEquals(11, User.objects.all().count())
-        
-        
+
+
     def _setup_view_restrictions(self):
         """
         Setup a view restriction with every type of the grant_on ACCESS_*
@@ -191,42 +189,50 @@ class ViewPermissionTests(SettingsOverrideTestCase):
         'group_b_b_ACCESS_DESCENDANTS'
         'group_d_ACCESS_PAGE'
         """
-        
+
         page = Page.objects.get(title_set__title="page_b")
         group = Group.objects.get(name__iexact=self.GROUPNAME_1)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_PAGE_AND_CHILDREN)
-        
+
         page = Page.objects.get(title_set__title="page_b_b")
         group = Group.objects.get(name__iexact=self.GROUPNAME_2)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_CHILDREN)
-        
+
         page = Page.objects.get(title_set__title="page_b")
         group = Group.objects.get(name__iexact=self.GROUPNAME_3)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_PAGE_AND_DESCENDANTS)
-        
+
         page = Page.objects.get(title_set__title="page_b_b")
         group = Group.objects.get(name__iexact=self.GROUPNAME_4)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_DESCENDANTS)
-        
+
         page = Page.objects.get(title_set__title="page_d")
         group = Group.objects.get(name__iexact=self.GROUPNAME_5)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_PAGE)
-        
+
         self.assertEquals(5, PagePermission.objects.all().count())
         self.assertEquals(0, GlobalPagePermission.objects.all().count())
-    
+
     def assertPageFound(self, url, client=None):
         if not client:
             client = Client()
         response = client.get(url)
         self.assertEquals(response.status_code, 200)
-    
+
     def assertPageNotFound(self, url, client=None):
         if not client:
             client = Client()
         response = client.get(url)
         self.assertEquals(response.status_code, 404)
-        
+
+    def assertViewAllowed(self, page, user):
+        request = self.get_request(user)
+        self.assertTrue(page.has_view_permission(request))
+
+    def assertViewNotAllowed(self, page, user):
+        request = self.get_request(user)
+        self.assertFalse(page.has_view_permission(request))
+
     def assertNodeMemberships(self, visible_page_ids, restricted_pages, public_page_ids):
         """
         test all visible page ids are either in_public and not in_restricted
@@ -242,7 +248,7 @@ class ViewPermissionTests(SettingsOverrideTestCase):
             self.assertTrue((in_public and not in_restricted) or
                              (not in_public and in_restricted),
                               msg="page_id %s in_public: %s, in_restricted: %s" % (page_id, in_public, in_restricted))
-                              
+
     def assertGrantedVisibility(self, all_pages, expected_granted_pages, username=None):
         """
         helper function to check the expected_granted_pages are 
@@ -255,11 +261,11 @@ class ViewPermissionTests(SettingsOverrideTestCase):
             user = User.objects.get(username__iexact=username)
         request = self.get_request(user)
         visible_page_ids = get_visible_pages(request, all_pages, self.site)
-    	self.assertEquals(len(visible_page_ids), len(expected_granted_pages))
+        self.assertEquals(len(visible_page_ids), len(expected_granted_pages))
         public_page_ids = Page.objects.filter(title_set__title__in=expected_granted_pages).values_list('id', flat=True)
         restricted_pages = Page.objects.exclude(title_set__title__in=expected_granted_pages).values_list('id', flat=True)
         self.assertNodeMemberships(visible_page_ids, restricted_pages, public_page_ids)
-        
+
     def get_request(self, user=None):
         # see tests/menu.py line 753
         attrs = {
@@ -268,7 +274,10 @@ class ViewPermissionTests(SettingsOverrideTestCase):
             'session': {},
         }
         return type('Request', (object,), attrs)
-        
+
+    def get_url_dict(self, pages, language='en'):
+        return dict(('/%s%s' % (language, page.get_absolute_url(language=language)), page) for page in pages)
+
 
 class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
     """
@@ -279,7 +288,7 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         'CMS_PERMISSION': True,
         'CMS_PUBLIC_FOR': 'all',
     }
-    
+
     def test_public_pages_anonymous_norestrictions(self):
         """
         All pages are visible to an anonymous user
@@ -288,7 +297,7 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
         request = self.get_request()
         visible_page_ids = get_visible_pages(request, all_pages, self.site)
         self.assertEquals(len(all_pages), len(visible_page_ids))
-        
+
     def test_public_menu_anonymous_user(self):
         """
         Anonymous user should only see the pages in the rendered menu
@@ -305,7 +314,7 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                    'page_d_d'
         ]
         self.assertGrantedVisibility(all_pages, granted)
- 
+
     def test_menu_access_page_and_children_group_1(self):
         """
         simulate behaviour of group b member
@@ -328,24 +337,18 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                    'page_d_c',
                    'page_d_d'
         ]
+        urls = self.get_url_dict(all_pages)
+        user = User.objects.get(username='user_1')
         self.assertGrantedVisibility(all_pages, granted, username='user_1')
-        client = Client()
-        login_ok = client.login(username='user_1', password='user_1')
-        self.assertEqual(login_ok , True)
-        url = "/en/page_b/"
-        self.assertPageFound(url, client)
-        url = "/en/page_b/page_b_b/"
-        self.assertPageFound(url, client)
+        self.assertViewAllowed(urls["/en/page_b/"], user)
+        self.assertViewAllowed(urls["/en/page_b/page_b_b/"], user)
         # descendant
-        url = "/en/page_b/page_b_b/page_b_b_a/"
-        self.assertPageNotFound(url, client)
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
         # group 5
-        url = "/en/page_d/"
-        self.assertPageNotFound(url, client)
+        self.assertViewNotAllowed(urls["/en/page_d/"], user)
         # should be public as only page_d is restricted
-        url = "/en/page_d/page_d_a/"
-        self.assertPageFound(url, client)
-        
+        self.assertViewAllowed(urls["/en/page_d/page_d_a/"], user)
+
     def test_menu_access_children_group_2(self):
         """
         simulate behaviour of group 2 member
@@ -368,20 +371,14 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                  'page_d_d',
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_2')
-        client = Client()
-        login_ok = client.login(username='user_2', password='user_2')
-        self.assertEqual(login_ok , True)
-        url = "/en/page_b/page_b_b/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_b/page_b_b/page_b_b_a/"
-        self.assertPageFound(url, client)
-        url = "/en/page_b/page_b_b/page_b_b_a/page_b_b_a_a/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_d/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_d/page_d_a/"
-        self.assertPageFound(url, client)
-        
+        urls = self.get_url_dict(all_pages)
+        user = User.objects.get(username='user_2')
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
+        self.assertViewAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/page_b_b_a/page_b_b_a_a/"], user)
+        self.assertViewNotAllowed(urls["/en/page_d/"], user)
+        self.assertViewAllowed(urls["/en/page_d/page_d_a/"], user)
+
     def test_menu_access_page_and_descendants_group_3(self):
         """
         simulate behaviour of group 3 member
@@ -410,18 +407,13 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                     'page_d_d',
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_3')
-        client = Client()
-        login_ok = client.login(username='user_3', password='user_3')
-        self.assertEqual(login_ok , True)
-        url = "/en/page_b/"
-        self.assertPageFound(url, client)
-        url = "/en/page_b/page_b_d/page_b_d_a/"
-        self.assertPageFound(url, client)
-        url = "/en/page_d/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_d/page_d_a/"
-        self.assertPageFound(url, client)
-        
+        urls = self.get_url_dict(all_pages)
+        user = User.objects.get(username='user_3')
+        self.assertViewAllowed(urls["/en/page_b/"], user)
+        self.assertViewAllowed(urls["/en/page_b/page_b_d/page_b_d_a/"], user)
+        self.assertViewNotAllowed(urls["/en/page_d/"], user)
+        self.assertViewAllowed(urls["/en/page_d/page_d_a/"], user)
+
     def test_menu_access_descendants_group_4(self):
         """
         simulate behaviour of group 4 member
@@ -442,20 +434,14 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                    'page_d_d',
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_4')
-        client = Client()
-        login_ok = client.login(username='user_4', password='user_4')
-        self.assertTrue(login_ok)
-        url = "/en/page_b/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_b/page_b_b/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_b/page_b_b/page_b_b_a/"
-        self.assertPageFound(url, client)
-        url = "/en/page_d/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_d/page_d_a/"
-        self.assertPageFound(url, client)
-        
+        urls = self.get_url_dict(all_pages)
+        user = User.objects.get(username='user_4')
+        self.assertViewNotAllowed(urls["/en/page_b/"], user)
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
+        self.assertViewAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
+        self.assertViewNotAllowed(urls["/en/page_d/"], user)
+        self.assertViewAllowed(urls["/en/page_d/page_d_a/"], user)
+
     def test_menu_access_page_group_5(self):
         """
         simulate behaviour of group b member
@@ -473,20 +459,14 @@ class ViewPermissionComplexMenuAllNodesTests(ViewPermissionTests):
                     'page_d_d',
         ]
         self.assertGrantedVisibility(all_pages, granted, username='user_5')
-        client = Client()
-        login_ok = client.login(username='user_5', password='user_5')
-        self.assertTrue(login_ok)
+        urls = self.get_url_dict(all_pages)
+        user = User.objects.get(username='user_5')
         # call /
-        url = "/en/page_b/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_b/page_b_b/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_b/page_b_b/page_b_b_a/"
-        self.assertPageNotFound(url, client)
-        url = "/en/page_d/"
-        self.assertPageFound(url, client)
-        url = "/en/page_d/page_d_a/"
-        self.assertPageFound(url, client)
+        self.assertViewNotAllowed(urls["/en/page_b/"], user)
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/"], user)
+        self.assertViewNotAllowed(urls["/en/page_b/page_b_b/page_b_b_a/"], user)
+        self.assertViewAllowed(urls["/en/page_d/"], user)
+        self.assertViewAllowed(urls["/en/page_d/page_d_a/"], user)
 
 
 class ViewPermissionTreeBugTests(ViewPermissionTests):
@@ -502,7 +482,7 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
         'CMS_PUBLIC_FOR': 'all',
     }
     GROUPNAME_6 = 'group_6_ACCESS_PAGE'  
-        
+
     def _setup_pages(self):
         """
         Tree Structure
@@ -532,7 +512,7 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
                 page_5,
                 page_6,
         ]
-    
+
     def _setup_user(self):
         user = User.objects.create(username='user_6', email='user_6@domain.com', is_active=True, is_staff=True)
         user.set_password(user.username)
@@ -540,7 +520,7 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
         group = Group.objects.create(name=self.GROUPNAME_6)
         group.user_set.add(user)
         group.save()
-        
+
     def _setup_permviewbug(self):
         """
         Setup group_6_ACCESS_PAGE view restriction 
@@ -549,7 +529,7 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
         group = Group.objects.get(name__iexact=self.GROUPNAME_6)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_PAGE_AND_CHILDREN)
         PagePermission.objects.create(can_view=True, group=group, page=page, grant_on=ACCESS_PAGE_AND_DESCENDANTS)
-            
+
     def test_pageforbug(self):
         all_pages = self._setup_pages()
         self._setup_user()
@@ -568,14 +548,13 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
                     'page_4',
                     'page_5',
         ]
-        # anonymous sees page_6 not
+        urls = self.get_url_dict(all_pages)
+        user = AnonymousUser()
+        # anonymous doesn't see page_6
         self.assertGrantedVisibility(all_pages, granted)
-        url = "/en/page_2/page_3/page_4/"
-        self.assertPageFound(url)
-        url = "/en/page_5/"
-        self.assertPageFound(url)
-        url = "/en/page_5/page_6/"
-        self.assertPageNotFound(url)
+        self.assertViewAllowed(urls["/en/page_2/page_3/page_4/"], user)
+        self.assertViewAllowed(urls["/en/page_5/"], user)
+        self.assertViewNotAllowed(urls["/en/page_5/page_6/"], user)
         # group member
         granted = [ 'page_1',
                     'page_2',
@@ -584,13 +563,12 @@ class ViewPermissionTreeBugTests(ViewPermissionTests):
                     'page_5',
                     'page_6',
         ]
+
         self.assertGrantedVisibility(all_pages, granted, username='user_6')
-        client = Client()
-        login_ok = client.login(username='user_6', password='user_6')
-        self.assertTrue(login_ok)
+        user = User.objects.get(username='user_6')
         url = "/en/page_2/page_3/page_4/"
-        self.assertPageFound(url, client)
+        self.assertViewAllowed(urls[url], user)
         url = "/en/page_5/page_6/"
-        self.assertPageFound(url, client)
-        
-        
+        self.assertViewAllowed(urls[url], user)
+
+
